[project]
name = "mgrc"
version = "1.0.0"
authors = [
  { name="Richard Craddock", email="yerbro@gmail.com" },
]
description = "Python3.10. Modules. A small, set of modules package."
readme = "README.md"
requires-python = ">=3.10"
classifiers = [
  "Programming Language :: Python :: 3",
  "License :: :: ",
  "Operating System :: OS Independent",
]
[project.urls]
"project py content" = "https://helpwithcode.w3spaces.com/python_imports.txt"
"not-project, My Website" = "https://glowinggoldenglobe.com"
"not-project, My-github-repositories list" = "https://github.com/GlowingGoldenGlobe"

